************************************
Specific Populations
************************************

ANNarchy provides a set of predefined ``Population`` objects to ease the definition of standard networks.


Class PoissonPopulation
=======================

.. autoclass:: ANNarchy.PoissonPopulation
   :members:


Class SpikeSourceArray
=======================

.. autoclass:: ANNarchy.SpikeSourceArray
   :members:


Class TimedArray
=======================

.. autoclass:: ANNarchy.TimedArray
   :members:


Class HomogeneousCorrelatedSpikeTrains
========================================

.. autoclass:: ANNarchy.HomogeneousCorrelatedSpikeTrains
   :members:


Class ImagePopulation
=======================

.. autoclass:: ANNarchy.extensions.image.ImagePopulation
   :members:


Class VideoPopulation
=======================

.. autoclass:: ANNarchy.extensions.image.VideoPopulation
   :members:

